abctools.AbjadObject
====================

.. inheritance-diagram:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject
   :private-bases:

.. autoclass:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject

Special Methods
---------------

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__eq__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__ge__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__gt__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__le__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__lt__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__ne__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__repr__

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__str__

   .. note:: Inherited from `__builtin__.object`
